@@ -253,19 +253,24 @@ OC.L10N.register(
     "Description" : "Beskrywing",
     "All messages" : "Alle boodskappe",
     "Off" : "Af",
+    "Pending" : "Hangend",
+    "Error" : "Fout",
+    "Active" : "Aktief",
     "Language" : "Taal",
     "Country" : "Land",
     "Status" : "Status",
     "Created at" : "Geskep om",
-    "Pending" : "Hangend",
-    "Error" : "Fout",
-    "Active" : "Aktief",
     "OK" : "Goed",
     "Checking …" : "Gaan tans na …",
-    "Back" : "Terug",
-    "Cancel" : "Kanselleer",
     "Confirm" : "Bevestig",
     "Reset" : "Herstel",
+    "Back" : "Terug",
+    "Cancel" : "Kanselleer",
+    "From" : "Van",
+    "To" : "Aan",
+    "Calendar" : "Kalender",
+    "Attendees" : "Bywoners",
+    "Save" : "Stoor",
     "This conversation is read-only" : "Hierdie gesprek is leesalleen",
     "Copy link" : "Kopieer skakel",
     "You" : "U",
@@ -276,16 +281,14 @@ OC.L10N.register(
     "Personal" : "Persoonlik",
     "Leave conversation" : "verlaat gesprek",
     "Delete conversation" : "Skrap gesprek",
-    "Save" : "Stoor",
     "Edit" : "Wysig",
     "Delete" : "Skrap",
     "Notifications" : "Kennisgewings",
-    "Login" : "Teken aan",
+    "Log in" : "Teken Aan",
     "Remove from favorites" : "Verwyder uit gunstelinge",
     "Add to favorites" : "Voeg by gunstelinge",
     "Users" : "Gebruikers",
     "Groups" : "Groepe",
-    "Loading" : "Laai tans..",
     "You are currently waiting in the lobby" : "U wag tans in die voorportaal",
     "None" : "Geen",
     "Devices" : "Toestelle",
@@ -297,15 +300,13 @@ OC.L10N.register(
     "Today" : "Vandag",
     "Yesterday" : "Gister",
     "Add participants" : "Voeg deelnemers toe",
-    "Close" : "Sluit",
-    "Password protect" : "Beskerm met 'n wagwoord",
     "Enter password" : "Voer wagwoord in",
-    "Settings" : "Instellings",
     "Send" : "Stuur",
+    "Settings" : "Instellings",
     "Join" : "Sluit aan",
     "guest" : "gas",
-    "Promote to moderator" : "Bevorder na moderator",
     "Remove participant" : "Verwyder deelnemer",
+    "Promote to moderator" : "Bevorder na moderator",
     "Chat" : "Klets",
     "Details" : "Besonderhede",
     "Privacy" : "Privaatheid",
@@ -315,17 +316,24 @@ OC.L10N.register(
     "Submit" : "Dien in",
     "User" : "Gebruiker",
     "Password" : "Wagwoord",
+    "Login" : "Teken aan",
     "Nickname" : "Bynaam",
     "Client ID" : "Kliënt-ID",
     "Media" : "Media",
     "Audio" : "Oudio",
     "Other" : "Ander",
     "Group" : "Groep",
+    "Please reload the page." : "Herlaai asseblief die bladsy.",
     "Do not disturb" : "Moenie pla nie",
     "Away" : "Weg",
     "Default" : "Verstek",
     "The password is wrong. Try again." : "Die wagwoord is verkeerd. Probeer weer.",
     "Android app" : "Android-toep",
-    "iOS app" : "iOS-toep"
+    "iOS app" : "iOS-toep",
+    "__language_name__" : "Afrikaans",
+    "Tasks" : "Take",
+    "Loading" : "Laai tans..",
+    "Close" : "Sluit",
+    "Password protect" : "Beskerm met 'n wagwoord"
 },
 "nplurals=2; plural=(n != 1);");
