@@ -90,12 +90,12 @@ OC.L10N.register(
     "{user} mentioned you in conversation {call}" : "{user} pieminēja jūs sarunā {call}",
     "A deleted user mentioned you in conversation {call}" : "Izdzēsts lietotājs pieminēja Tevi sarunā {call}",
     "A guest mentioned you in conversation {call}" : "Kāds viesis jūs pieminēja sarunā {call}",
-    "{user} invited you to a private conversation" : "{user} uzaicināja jūs uz privātu sarunu",
-    "Join call" : "Pievienoties zvanam",
     "{user} invited you to a group conversation: {call}" : "{user} uzaicināja jūs uz grupas sarunu: {call}",
+    "Join call" : "Pievienoties zvanam",
     "A group call has started in {call}" : "Grupas zvans ir sācies {call}",
     "Open settings" : "Atvērt iestatījumus",
     "error" : "kļūda",
+    "Open Talk" : "Atvērt Talk",
     "Avatar image is not square" : "Avatar attēls nav kvadrāts",
     "Andorra" : "Andora",
     "United Arab Emirates" : "Apvienotie Arābu Emirāti",
@@ -381,6 +381,7 @@ OC.L10N.register(
     "Reset" : "Atiestatīt",
     "Back" : "Atpakaļ",
     "Cancel" : "Atcelt",
+    "Open Calendar" : "Atvērt kalendāru",
     "Loading …" : "Ielādē…",
     "No upcoming events" : "Nav gaidāmu notikumu",
     "From" : "No",
@@ -418,6 +419,7 @@ OC.L10N.register(
     "Yes" : "Jā",
     "Delete conversation" : "Dzēst sarunu",
     "Password protection" : "Password protection",
+    "Open conversation" : "Atvērt sarunu",
     "Edit" : "Labot",
     "Delete" : "Dzēst",
     "Notifications" : "Paziņojumi",
@@ -429,6 +431,7 @@ OC.L10N.register(
     "Clear filter" : "Notīrīt atlasi",
     "Users" : "Lietotāji",
     "Groups" : "Grupas",
+    "Open conversations" : "Atvērt sarunas",
     "None" : "Nav",
     "Devices" : "Ierīces",
     "No audio" : "Nav audio",
@@ -524,6 +527,7 @@ OC.L10N.register(
     "Call with {user1}, {user2} and {user3} (Duration {duration})" : "Saruna ar {user1}, {user2} un {user3} ( Ilgums {duration})",
     "Call with {user1}, {user2}, {user3} and {user4} (Duration {duration})" : "Saruna ar {user1}, {user2}, {user3} un {user4} ( Ilgums {duration})",
     "Call with {user1}, {user2}, {user3}, {user4} and {user5} (Duration {duration})" : "Saruna ar {user1}, {user2}, {user3}, {user4} un {user5} ( Ilgums {duration})",
+    "{user} invited you to a private conversation" : "{user} uzaicināja jūs uz privātu sarunu",
     "Moderators" : "Regulētāji",
     "Commands" : "Komandas",
     "Command" : "Komanda",
