@@ -27,6 +27,8 @@ OC.L10N.register(
     "Talk updates ✅" : "Atualizações do Falar ✅",
     "System created the conversation" : "O sistema criou a conversa",
     "Message deleted by author" : "Mensagem apagada pelo autor",
+    "Administration" : "Administração",
+    "System" : "Sistema",
     "Talk conversations" : "Conversas no Talk",
     "Talk to %s" : "Falar com %s",
     "File is too big" : "O ficheiro é demasiado grande",
@@ -288,6 +290,8 @@ OC.L10N.register(
     "Restricted" : "Restrito",
     "Personal" : "Pessoal",
     "Leave conversation" : "Sair da conversação",
+    "No" : "Não",
+    "Yes" : "Sim",
     "Delete conversation" : "Eliminar conversação",
     "Password protection" : "Protegido por palavra-passe",
     "Set a password" : "Definir uma palavra-passe",
@@ -297,13 +301,13 @@ OC.L10N.register(
     "Log in" : "Iniciar sessão",
     "Remove from favorites" : "Remover de favoritos",
     "Add to favorites" : "Adicionar aos favoritos",
-    "Users" : "Utilizadores",
-    "Groups" : "Grupos",
-    "Teams" : "Grupos",
     "Create a new conversation" : "Criar nova conversa",
     "Join open conversations" : "Juntar-me a conversas abertas",
     "Clear filter" : "Limpar filtro",
     "Talk settings" : "Definições do Falar",
+    "Users" : "Utilizadores",
+    "Groups" : "Grupos",
+    "Teams" : "Grupos",
     "None" : "Nenhum",
     "Invalid path selected" : "Caminho inválido selecionado",
     "Upload" : "Enviar",
