@@ -2,37 +2,19 @@
 
 declare(strict_types=1);
 /**
- * @copyright Copyright (c) 2016 Lukas Reschke <lukas@statuscode.ch>
- * @copyright Copyright (c) 2016 Joas Schilling <coding@schilljs.com>
- *
- * @author Lukas Reschke <lukas@statuscode.ch>
- * @author Joas Schilling <coding@schilljs.com>
- *
- * @license GNU AGPL version 3 or any later version
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Affero General Public License as
- * published by the Free Software Foundation, either version 3 of the
- * License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU Affero General Public License for more details.
- *
- * You should have received a copy of the GNU Affero General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
+ * SPDX-FileCopyrightText: 2016 Nextcloud GmbH and Nextcloud contributors
+ * SPDX-License-Identifier: AGPL-3.0-or-later
  */
 
 namespace OCA\Talk;
 
-use OCA\Talk\Events\SignalingRoomPropertiesEvent;
+use OCA\Talk\Events\BeforeSignalingRoomPropertiesSentEvent;
 use OCA\Talk\Exceptions\ParticipantNotFoundException;
 use OCA\Talk\Model\Attendee;
 use OCA\Talk\Model\SelectHelper;
 use OCA\Talk\Model\Session;
 use OCA\Talk\Service\ParticipantService;
+use OCA\Talk\Service\RecordingService;
 use OCA\Talk\Service\RoomService;
 use OCP\AppFramework\Utility\ITimeFactory;
 use OCP\Comments\IComment;
@@ -55,6 +37,14 @@ class Room {
 	public const TYPE_PUBLIC = 3;
 	public const TYPE_CHANGELOG = 4;
 	public const TYPE_ONE_TO_ONE_FORMER = 5;
+	public const TYPE_NOTE_TO_SELF = 6;
+
+	public const OBJECT_TYPE_EMAIL = 'emails';
+	public const OBJECT_TYPE_FILE = 'file';
+	public const OBJECT_TYPE_PHONE = 'phone';
+	public const OBJECT_TYPE_VIDEO_VERIFICATION = 'share:password';
+	public const OBJECT_TYPE_SAMPLE = 'sample';
+	public const OBJECT_TYPE_EVENT = 'event';
 
 	public const RECORDING_NONE = 0;
 	public const RECORDING_VIDEO = 1;
@@ -63,16 +53,6 @@ class Room {
 	public const RECORDING_AUDIO_STARTING = 4;
 	public const RECORDING_FAILED = 5;
 
-	/** @deprecated Use self::TYPE_UNKNOWN */
-	public const UNKNOWN_CALL = self::TYPE_UNKNOWN;
-	/** @deprecated Use self::TYPE_ONE_TO_ONE */
-	public const ONE_TO_ONE_CALL = self::TYPE_ONE_TO_ONE;
-	/** @deprecated Use self::TYPE_GROUP */
-	public const GROUP_CALL = self::TYPE_GROUP;
-	/** @deprecated Use self::TYPE_PUBLIC */
-	public const PUBLIC_CALL = self::TYPE_PUBLIC;
-	/** @deprecated Use self::TYPE_CHANGELOG */
-	public const CHANGELOG_CONVERSATION = self::TYPE_CHANGELOG;
 
 	public const READ_WRITE = 0;
 	public const READ_ONLY = 1;
@@ -83,12 +63,12 @@ class Room {
 	public const LISTABLE_NONE = 0;
 
 	/**
-	 * Searchable by all regular users and moderators, even when not joined, excluding users from the guest app
+	 * Searchable by all regular users and moderators, even when not joined, excluding users created with the Guests app
 	 */
 	public const LISTABLE_USERS = 1;
 
 	/**
-	 * Searchable by everyone, which includes guest users (from guest app), even when not joined
+	 * Searchable by everyone, which includes users created with the Guests app, even when not joined
 	 */
 	public const LISTABLE_ALL = 2;
 
@@ -97,188 +77,77 @@ class Room {
 	public const START_CALL_MODERATORS = 2;
 	public const START_CALL_NOONE = 3;
 
-	public const PARTICIPANT_REMOVED = 'remove';
-	public const PARTICIPANT_REMOVED_ALL = 'remove_all';
-	public const PARTICIPANT_LEFT = 'leave';
+	public const DESCRIPTION_MAXIMUM_LENGTH = 2000;
 
-	public const EVENT_AFTER_ROOM_CREATE = self::class . '::createdRoom';
-	public const EVENT_BEFORE_ROOM_DELETE = self::class . '::preDeleteRoom';
-	public const EVENT_AFTER_ROOM_DELETE = self::class . '::postDeleteRoom';
-	public const EVENT_BEFORE_NAME_SET = self::class . '::preSetName';
-	public const EVENT_AFTER_NAME_SET = self::class . '::postSetName';
-	public const EVENT_BEFORE_DESCRIPTION_SET = self::class . '::preSetDescription';
-	public const EVENT_AFTER_DESCRIPTION_SET = self::class . '::postSetDescription';
-	public const EVENT_BEFORE_PASSWORD_SET = self::class . '::preSetPassword';
-	public const EVENT_AFTER_PASSWORD_SET = self::class . '::postSetPassword';
-	public const EVENT_BEFORE_TYPE_SET = self::class . '::preSetType';
-	public const EVENT_AFTER_TYPE_SET = self::class . '::postSetType';
-	public const EVENT_BEFORE_READONLY_SET = self::class . '::preSetReadOnly';
-	public const EVENT_AFTER_READONLY_SET = self::class . '::postSetReadOnly';
-	public const EVENT_BEFORE_LISTABLE_SET = self::class . '::preSetListable';
-	public const EVENT_AFTER_LISTABLE_SET = self::class . '::postSetListable';
-	public const EVENT_BEFORE_LOBBY_STATE_SET = self::class . '::preSetLobbyState';
-	public const EVENT_AFTER_LOBBY_STATE_SET = self::class . '::postSetLobbyState';
-	public const EVENT_BEFORE_END_CALL_FOR_EVERYONE = self::class . '::preEndCallForEveryone';
-	public const EVENT_AFTER_END_CALL_FOR_EVERYONE = self::class . '::postEndCallForEveryone';
-	public const EVENT_BEFORE_SIP_ENABLED_SET = self::class . '::preSetSIPEnabled';
-	public const EVENT_AFTER_SIP_ENABLED_SET = self::class . '::postSetSIPEnabled';
-	public const EVENT_BEFORE_PERMISSIONS_SET = self::class . '::preSetPermissions';
-	public const EVENT_AFTER_PERMISSIONS_SET = self::class . '::postSetPermissions';
-	public const EVENT_BEFORE_USERS_ADD = self::class . '::preAddUsers';
-	public const EVENT_AFTER_USERS_ADD = self::class . '::postAddUsers';
-	public const EVENT_BEFORE_PARTICIPANT_TYPE_SET = self::class . '::preSetParticipantType';
-	public const EVENT_AFTER_PARTICIPANT_TYPE_SET = self::class . '::postSetParticipantType';
-	public const EVENT_BEFORE_PARTICIPANT_PERMISSIONS_SET = self::class . '::preSetParticipantPermissions';
-	public const EVENT_AFTER_PARTICIPANT_PERMISSIONS_SET = self::class . '::postSetParticipantPermissions';
-	public const EVENT_BEFORE_USER_REMOVE = self::class . '::preRemoveUser';
-	public const EVENT_AFTER_USER_REMOVE = self::class . '::postRemoveUser';
-	public const EVENT_BEFORE_PARTICIPANT_REMOVE = self::class . '::preRemoveBySession';
-	public const EVENT_AFTER_PARTICIPANT_REMOVE = self::class . '::postRemoveBySession';
-	public const EVENT_BEFORE_ROOM_CONNECT = self::class . '::preJoinRoom';
-	public const EVENT_AFTER_ROOM_CONNECT = self::class . '::postJoinRoom';
-	public const EVENT_BEFORE_ROOM_DISCONNECT = self::class . '::preUserDisconnectRoom';
-	public const EVENT_AFTER_ROOM_DISCONNECT = self::class . '::postUserDisconnectRoom';
-	public const EVENT_BEFORE_GUEST_CONNECT = self::class . '::preJoinRoomGuest';
-	public const EVENT_AFTER_GUEST_CONNECT = self::class . '::postJoinRoomGuest';
-	public const EVENT_PASSWORD_VERIFY = self::class . '::verifyPassword';
-	public const EVENT_BEFORE_GUESTS_CLEAN = self::class . '::preCleanGuests';
-	public const EVENT_AFTER_GUESTS_CLEAN = self::class . '::postCleanGuests';
-	public const EVENT_BEFORE_SESSION_JOIN_CALL = self::class . '::preSessionJoinCall';
-	public const EVENT_AFTER_SESSION_JOIN_CALL = self::class . '::postSessionJoinCall';
-	public const EVENT_BEFORE_SESSION_UPDATE_CALL_FLAGS = self::class . '::preSessionUpdateCallFlags';
-	public const EVENT_AFTER_SESSION_UPDATE_CALL_FLAGS = self::class . '::postSessionUpdateCallFlags';
-	public const EVENT_BEFORE_SESSION_LEAVE_CALL = self::class . '::preSessionLeaveCall';
-	public const EVENT_AFTER_SESSION_LEAVE_CALL = self::class . '::postSessionLeaveCall';
-	public const EVENT_BEFORE_SIGNALING_PROPERTIES = self::class . '::beforeSignalingProperties';
-	public const EVENT_BEFORE_SET_MESSAGE_EXPIRATION = self::class . '::beforeSetMessageExpiration';
-	public const EVENT_AFTER_SET_MESSAGE_EXPIRATION = self::class . '::afterSetMessageExpiration';
-	public const EVENT_BEFORE_SET_BREAKOUT_ROOM_MODE = self::class . '::beforeSetBreakoutRoomMode';
-	public const EVENT_AFTER_SET_BREAKOUT_ROOM_MODE = self::class . '::afterSetBreakoutRoomMode';
-	public const EVENT_BEFORE_SET_BREAKOUT_ROOM_STATUS = self::class . '::beforeSetBreakoutRoomStatus';
-	public const EVENT_AFTER_SET_BREAKOUT_ROOM_STATUS = self::class . '::afterSetBreakoutRoomStatus';
-	public const EVENT_BEFORE_SET_CALL_RECORDING = self::class . '::beforeSetCallRecording';
-	public const EVENT_AFTER_SET_CALL_RECORDING = self::class . '::afterSetCallRecording';
-	public const EVENT_BEFORE_AVATAR_SET = self::class . '::preSetAvatar';
-	public const EVENT_AFTER_AVATAR_SET = self::class . '::postSetAvatar';
+	public const HAS_FEDERATION_NONE = 0;
+	public const HAS_FEDERATION_TALKv1 = 1;
 
-	public const DESCRIPTION_MAXIMUM_LENGTH = 500;
-
-	private Manager $manager;
-	private IDBConnection $db;
-	private IEventDispatcher $dispatcher;
-	private ITimeFactory $timeFactory;
-
-	private int $id;
-	private int $type;
-	private int $readOnly;
-	private int $listable;
-	private int $messageExpiration;
-	private int $lobbyState;
-	private int $sipEnabled;
-	private ?int $assignedSignalingServer;
-	private ?\DateTime $lobbyTimer;
-	private string $token;
-	private string $name;
-	private string $description;
-	private string $password;
-	private string $avatar;
-	private string $remoteServer;
-	private string $remoteToken;
-	private int $activeGuests;
-	private int $defaultPermissions;
-	private int $callPermissions;
-	private int $callFlag;
-	private ?\DateTime $activeSince;
-	private ?\DateTime $lastActivity;
-	private int $lastMessageId;
-	private ?IComment $lastMessage;
-	private string $objectType;
-	private string $objectId;
-	private int $breakoutRoomMode;
-	private int $breakoutRoomStatus;
-	private int $callRecording;
+	public const MENTION_PERMISSIONS_EVERYONE = 0;
+	public const MENTION_PERMISSIONS_MODERATORS = 1;
 
 	protected ?string $currentUser = null;
 	protected ?Participant $participant = null;
 
+	/**
+	 * @psalm-param Room::TYPE_* $type
+	 * @psalm-param RecordingService::CONSENT_REQUIRED_* $recordingConsent
+	 * @psalm-param int-mask-of<self::HAS_FEDERATION_*> $hasFederation
+	 */
 	public function __construct(
-		Manager $manager,
-		IDBConnection $db,
-		IEventDispatcher $dispatcher,
-		ITimeFactory $timeFactory,
-		int $id,
-		int $type,
-		int $readOnly,
-		int $listable,
-		int $messageExpiration,
-		int $lobbyState,
-		int $sipEnabled,
-		?int $assignedSignalingServer,
-		string $token,
-		string $name,
-		string $description,
-		string $password,
-		string $avatar,
-		string $remoteServer,
-		string $remoteToken,
-		int $activeGuests,
-		int $defaultPermissions,
-		int $callPermissions,
-		int $callFlag,
-		?\DateTime $activeSince,
-		?\DateTime $lastActivity,
-		int $lastMessageId,
-		?IComment $lastMessage,
-		?\DateTime $lobbyTimer,
-		string $objectType,
-		string $objectId,
-		int $breakoutRoomMode,
-		int $breakoutRoomStatus,
-		int $callRecording,
+		private Manager $manager,
+		private IDBConnection $db,
+		private IEventDispatcher $dispatcher,
+		private ITimeFactory $timeFactory,
+		private int $id,
+		private int $type,
+		private int $readOnly,
+		private int $listable,
+		private int $messageExpiration,
+		private int $lobbyState,
+		private int $sipEnabled,
+		private ?int $assignedSignalingServer,
+		private string $token,
+		private string $name,
+		private string $description,
+		private string $password,
+		private string $avatar,
+		private string $remoteServer,
+		private string $remoteToken,
+		private int $defaultPermissions,
+		private int $callPermissions,
+		private int $callFlag,
+		private ?\DateTime $activeSince,
+		private ?\DateTime $lastActivity,
+		private int $lastMessageId,
+		private ?IComment $lastMessage,
+		private ?\DateTime $lobbyTimer,
+		private string $objectType,
+		private string $objectId,
+		private int $breakoutRoomMode,
+		private int $breakoutRoomStatus,
+		private int $callRecording,
+		private int $recordingConsent,
+		private int $hasFederation,
+		private int $mentionPermissions,
 	) {
-		$this->manager = $manager;
-		$this->db = $db;
-		$this->dispatcher = $dispatcher;
-		$this->timeFactory = $timeFactory;
-		$this->id = $id;
-		$this->type = $type;
-		$this->readOnly = $readOnly;
-		$this->listable = $listable;
-		$this->messageExpiration = $messageExpiration;
-		$this->lobbyState = $lobbyState;
-		$this->sipEnabled = $sipEnabled;
-		$this->assignedSignalingServer = $assignedSignalingServer;
-		$this->token = $token;
-		$this->name = $name;
-		$this->description = $description;
-		$this->password = $password;
-		$this->avatar = $avatar;
-		$this->remoteServer = $remoteServer;
-		$this->remoteToken = $remoteToken;
-		$this->activeGuests = $activeGuests;
-		$this->defaultPermissions = $defaultPermissions;
-		$this->callPermissions = $callPermissions;
-		$this->callFlag = $callFlag;
-		$this->activeSince = $activeSince;
-		$this->lastActivity = $lastActivity;
-		$this->lastMessageId = $lastMessageId;
-		$this->lastMessage = $lastMessage;
-		$this->lobbyTimer = $lobbyTimer;
-		$this->objectType = $objectType;
-		$this->objectId = $objectId;
-		$this->breakoutRoomMode = $breakoutRoomMode;
-		$this->breakoutRoomStatus = $breakoutRoomStatus;
-		$this->callRecording = $callRecording;
 	}
 
 	public function getId(): int {
 		return $this->id;
 	}
 
+	/**
+	 * @return int
+	 * @psalm-return Room::TYPE_*
+	 */
 	public function getType(): int {
 		return $this->type;
 	}
 
+	/**
+	 * @param int $type
+	 * @psalm-param Room::TYPE_* $type
+	 */
 	public function setType(int $type): void {
 		$this->type = $type;
 	}
@@ -289,9 +158,9 @@ class Room {
 
 	/**
 	 * @param int $readOnly Currently it is only allowed to change between
-	 * 						`self::READ_ONLY` and `self::READ_WRITE`
-	 * 						Also it's only allowed on rooms of type
-	 * 						`self::TYPE_GROUP` and `self::TYPE_PUBLIC`
+	 *                      `self::READ_ONLY` and `self::READ_WRITE`
+	 *                      Also it's only allowed on rooms of type
+	 *                      `self::TYPE_GROUP` and `self::TYPE_PUBLIC`
 	 */
 	public function setReadOnly(int $readOnly): void {
 		$this->readOnly = $readOnly;
@@ -303,8 +172,8 @@ class Room {
 
 	/**
 	 * @param int $newState New listable scope from self::LISTABLE_*
-	 * 						Also it's only allowed on rooms of type
-	 * 						`self::TYPE_GROUP` and `self::TYPE_PUBLIC`
+	 *                      Also it's only allowed on rooms of type
+	 *                      `self::TYPE_GROUP` and `self::TYPE_PUBLIC`
 	 */
 	public function setListable(int $newState): void {
 		$this->listable = $newState;
@@ -379,7 +248,7 @@ class Room {
 				/** @var RoomService $roomService */
 				$roomService = Server::get(RoomService::class);
 				$roomService->setName($this, json_encode($users), '');
-			} elseif (strpos($this->name, '["') !== 0) {
+			} elseif (!str_starts_with($this->name, '["')) {
 				// TODO use DI
 				$participantService = Server::get(ParticipantService::class);
 				// Not the json array, but the old fallback when someone left
@@ -427,17 +296,9 @@ class Room {
 		$this->description = $description;
 	}
 
-	/**
-	 * @deprecated Use ParticipantService::getGuestCount() instead
-	 * @return int
-	 */
-	public function getActiveGuests(): int {
-		return $this->activeGuests;
-	}
-
 	public function resetActiveSince(): void {
-		$this->activeGuests = 0;
 		$this->activeSince = null;
+		$this->callFlag = Participant::FLAG_DISCONNECTED;
 	}
 
 	public function getDefaultPermissions(): int {
@@ -448,10 +309,16 @@ class Room {
 		$this->defaultPermissions = $defaultPermissions;
 	}
 
+	/**
+	 * @deprecated
+	 */
 	public function getCallPermissions(): int {
-		return $this->callPermissions;
+		return Attendee::PERMISSIONS_DEFAULT;
 	}
 
+	/**
+	 * @deprecated
+	 */
 	public function setCallPermissions(int $callPermissions): void {
 		$this->callPermissions = $callPermissions;
 	}
@@ -472,7 +339,19 @@ class Room {
 		$this->lastActivity = $now;
 	}
 
+	public function getLastMessageId(): int {
+		return $this->lastMessageId;
+	}
+
+	public function setLastMessageId(int $lastMessageId): void {
+		$this->lastMessageId = $lastMessageId;
+	}
+
 	public function getLastMessage(): ?IComment {
+		if ($this->isFederatedConversation()) {
+			return null;
+		}
+
 		if ($this->lastMessageId && $this->lastMessage === null) {
 			$this->lastMessage = $this->manager->loadLastCommentInfo($this->lastMessageId);
 			if ($this->lastMessage === null) {
@@ -485,7 +364,7 @@ class Room {
 
 	public function setLastMessage(IComment $message): void {
 		$this->lastMessage = $message;
-		$this->lastMessageId = (int) $message->getId();
+		$this->lastMessageId = (int)$message->getId();
 	}
 
 	public function getObjectType(): string {
@@ -520,15 +399,20 @@ class Room {
 		return $this->remoteServer;
 	}
 
+	/**
+	 * Whether the conversation is a "proxy conversation" or the original hosted conversation
+	 * @return bool
+	 */
+	public function isFederatedConversation(): bool {
+		return $this->remoteServer !== '';
+	}
+
 	public function getRemoteToken(): string {
 		return $this->remoteToken;
 	}
 
-	public function isFederatedRemoteRoom(): bool {
-		return $this->remoteServer !== '';
-	}
-
 	public function setParticipant(?string $userId, Participant $participant): void {
+		// FIXME Also used with cloudId, need actorType checking?
 		$this->currentUser = $userId;
 		$this->participant = $participant;
 	}
@@ -558,8 +442,8 @@ class Room {
 			$properties['participant-list'] = 'refresh';
 		}
 
-		$event = new SignalingRoomPropertiesEvent($this, $userId, $properties);
-		$this->dispatcher->dispatch(self::EVENT_BEFORE_SIGNALING_PROPERTIES, $event);
+		$event = new BeforeSignalingRoomPropertiesSentEvent($this, $userId, $properties);
+		$this->dispatcher->dispatchTyped($event);
 		return $event->getProperties();
 	}
 
@@ -623,14 +507,11 @@ class Room {
 		return $this->manager->createParticipantObject($this, $row);
 	}
 
-	public function setActiveSince(\DateTime $since, int $callFlag, bool $isGuest): void {
+	public function setActiveSince(\DateTime $since, int $callFlag): void {
 		if (!$this->activeSince) {
 			$this->activeSince = $since;
 		}
 		$this->callFlag |= $callFlag;
-		if ($isGuest) {
-			$this->activeGuests++;
-		}
 	}
 
 	public function getBreakoutRoomMode(): int {
@@ -656,4 +537,42 @@ class Room {
 	public function setCallRecording(int $callRecording): void {
 		$this->callRecording = $callRecording;
 	}
+
+	/**
+	 * @return RecordingService::CONSENT_REQUIRED_*
+	 */
+	public function getRecordingConsent(): int {
+		return $this->recordingConsent;
+	}
+
+	/**
+	 * @param int $recordingConsent
+	 * @psalm-param RecordingService::CONSENT_REQUIRED_* $recordingConsent
+	 */
+	public function setRecordingConsent(int $recordingConsent): void {
+		$this->recordingConsent = $recordingConsent;
+	}
+
+	/**
+	 * @psalm-return int-mask-of<self::HAS_FEDERATION_*>
+	 */
+	public function hasFederatedParticipants(): int {
+		return $this->hasFederation;
+	}
+
+	/**
+	 * @param int $hasFederation
+	 * @psalm-param int-mask-of<self::HAS_FEDERATION_*> $hasFederation (bit map)
+	 */
+	public function setFederatedParticipants(int $hasFederation): void {
+		$this->hasFederation = $hasFederation;
+	}
+
+	public function getMentionPermissions(): int {
+		return $this->mentionPermissions;
+	}
+
+	public function setMentionPermissions(int $mentionPermissions): void {
+		$this->mentionPermissions = $mentionPermissions;
+	}
 }
