@@ -65,6 +65,7 @@ class RoomFormatter {
 		?array $statuses = null,
 		bool $isSIPBridgeRequest = false,
 		bool $isListingBreakoutRooms = false,
+		bool $skipLastMessage = false,
 	): array {
 		return $this->formatRoomV4(
 			$responseFormat,
@@ -74,6 +75,7 @@ class RoomFormatter {
 			$statuses,
 			$isSIPBridgeRequest,
 			$isListingBreakoutRooms,
+			$skipLastMessage,
 		);
 	}
 
@@ -89,6 +91,7 @@ class RoomFormatter {
 		?array $statuses,
 		bool $isSIPBridgeRequest,
 		bool $isListingBreakoutRooms,
+		bool $skipLastMessage,
 	): array {
 		$roomData = [
 			'id' => $room->getId(),
@@ -386,7 +389,7 @@ class RoomFormatter {
 			}
 		}
 
-		$lastMessage = $room->getLastMessage();
+		$lastMessage = $skipLastMessage ? null : $room->getLastMessage();
 		if (!$room->isFederatedConversation() && $lastMessage instanceof IComment) {
 			$lastMessageData = $this->formatLastMessage(
 				$responseFormat,
@@ -435,7 +438,7 @@ class RoomFormatter {
 		IComment $lastMessage,
 	): ?array {
 		$message = $this->messageParser->createMessage($room, $participant, $lastMessage, $this->l10n);
-		$this->messageParser->parseMessage($message);
+		$this->messageParser->parseMessage($message, true);
 
 		if (!$message->getVisibility()) {
 			return null;
